@@ -197,192 +197,6 @@ plot.fmridata <- function(x, anatomic = NULL , maxpvalue = 0.05, spm = TRUE,
   if (exists("tt")) invisible(tt)
 }
 
-plot.fmripvalue.old <- function(x, template=NULL, mask=NULL,
-                            view=c("axial","coronal","sagittal","orthographic"), slices=NULL, ncol=1, nrow=1, center=NULL, ...){
-  # check arguments
-  if(!view%in%c("axial","coronal","sagittal","orthographic")) stop("view needs to be 'axial', 'coronal', 'sagittal' or 'orthographic'")
-  pvalue <- x$pvalue
-	alpha <- x$alpha
-	hdr = x$header
-  ddim <- dim(pvalue)
-  if(is.null(template)) template <- pvalue
-  if(any(ddim!=dim(template))) stop("template dimension does not match")
-  if(is.null(mask)) mask <- array(TRUE,dim(pvalue))
-  if(any(ddim!=dim(mask))) stop("mask dimension does not match")
-  pvalue[pvalue>=alpha] <- NA
-  pvalue[!mask] <- NA
-	pvalue[pvalue<1e-10] <- 1e-10
-  lpvalue <- -log(pvalue)
-  if(view!="orthographic"&is.null(slices)){
-    nslice <- ncol*nrow
-    slices <- switch(view,
-                     "sagittal"=sort(order(apply(lpvalue,1,sum,na.rm=TRUE),decreasing=TRUE)[1:nslice]),
-                     "coronal"=sort(order(apply(lpvalue,2,sum,na.rm=TRUE),decreasing=TRUE)[1:nslice]),
-                     "axial"=sort(order(apply(lpvalue,3,sum,na.rm=TRUE),decreasing=TRUE)[1:nslice]))
-  }
-  if(view=="orthographic"&is.null(center)){
-    center <- c(order(apply(lpvalue,1,sum,na.rm=TRUE),decreasing=TRUE)[1],
-                order(apply(lpvalue,2,sum,na.rm=TRUE),decreasing=TRUE)[1],
-                order(apply(lpvalue,3,sum,na.rm=TRUE),decreasing=TRUE)[1])
-    if(!mask[center[1],center[2],center[3]]) stop("Please specify center within brain mask\n")
-  }
-  n1 <- ddim[1]
-  n2 <- ddim[2]
-  n3 <- ddim[3]
-  indx <- (1:n1)[apply(mask,1,any)]
-  indy <- (1:n2)[apply(mask,2,any)]
-  indz <- (1:n3)[apply(mask,3,any)]
-  pvalue <- pvalue[indx,indy,indz]
-  lpvalue <- lpvalue[indx,indy,indz]
-  rlp <- range(lpvalue,na.rm=TRUE)
-  template <- template[indx,indy,indz]
-  n1 <- length(indx)
-  n2 <- length(indy)
-  n3 <- length(indz)
-  if(view=="orthographic"){
-    center[1] <- (1:n1)[indx==center[1]]
-    center[2] <- (1:n2)[indy==center[2]]
-    center[3] <- (1:n3)[indz==center[3]]
-  } else {
-    slices <- switch(view,
-                     "sagittal"=slices[slices<=max(indx)],
-                     "coronal"=slices[slices<=max(indy)],
-                     "axial"=slices[slices<=max(indz)]
-    )
-    slices <- switch(view,
-                     "sagittal"=slices-min(indx)+1,
-                     "coronal"=slices-min(indy)+1,
-                     "axial"=slices-min(indz)+1
-    )
-		nslice <- length(slices)
-    nrow <- ceiling(nslice/ncol)
-  }
-  oldpar <- par(mar=c(2.5,2.5,2.5,.1),mgp=c(1.5,.5,0))
-  if(view=="orthographic"){
-    pdim <- hdr$pixdim[2:4]
-    if (is.null(pdim)) {
-      warning("pixdim is not found, making all 1")
-      pdim = rep(1, 8)
-    }
-		n12 <- max(n1,n2)
-    wh <- 2*n1+n2+n12/8
-    mat <- matrix(c(1,2,3,4),1,4)
-    layout(mat,widths=c(n2,n1,n1,n12/8)/wh,
-           heights=1)
-    image(-indy[n2:1]*pdim[2],indz*pdim[3],template[center[1],n2:1,],col=grey(0:255/255),asp=TRUE,xlab="-yind")
-    title("sagittal")
-    lines(-indy[c(1,n2)]*pdim[2],rep(indz[center[3]]*pdim[3],2),col=2)
-    lines(rep(-indy[center[2]]*pdim[2],2),indz[c(1,n3)]*pdim[3],col=2)
-    image(-indy[n2:1]*pdim[2],indz*pdim[3],lpvalue[center[1],n2:1,],zlim=rlp,add=TRUE,col=heat.colors(256),asp=TRUE)
-    image(indx*pdim[1],indz*pdim[3],template[,center[2],],col=grey(0:255/255),asp=TRUE)
-    title("coronal")
-    lines(indx[c(1,n1)]*pdim[1],rep(indz[center[3]]*pdim[3],2),col=2)
-    lines(rep(indx[center[1]]*pdim[1],2),indz[c(1,n3)]*pdim[3],col=2)
-    image(indx*pdim[1],indz*pdim[3],lpvalue[,center[2],],zlim=rlp,add=TRUE,col=heat.colors(256),asp=TRUE)
-    image(indx*pdim[1],indy*pdim[2],template[,,center[3]],col=grey(0:255/255),asp=TRUE)
-    title("axial")
-    lines(indx[c(1,n1)]*pdim[1],rep(indy[center[2]]*pdim[2],2),col=2)
-    lines(rep(indx[center[1]]*pdim[1],2),indy[c(1,n2)]*pdim[2],col=2)
-    image(indx*pdim[1],indy*pdim[2],lpvalue[,,center[3]],zlim=rlp,add=TRUE,col=heat.colors(256),asp=TRUE)
-    scalep <- seq(rlp[1],rlp[2],length=256)
-    scalep <- t(matrix(scalep,length(scalep),10))
-    image(1:10,scalep[1,],scalep,col=heat.colors(256),xaxt="n",xlab="",ylab="-log(pvalue)")
-  } else {
-    mat <- matrix(0,nrow,ncol+1)
-    for(i in 1:nrow){
-      mat[i,1:ncol] <- (i-1)*(ncol+1)+1:ncol
-      mat[i,ncol+1] <- i*(ncol+1)
-    }
-    if(view=="sagittal"){
-      widths <- c(rep(n2,ncol),n2/max(1,10-ncol))
-      heights <- rep(n3,nrow)
-    }
-    if(view=="coronal"){
-      widths <- c(rep(n1,ncol),n1/max(1,10-ncol))
-      heights <- rep(n3,nrow)
-    }
-    if(view=="axial"){
-      widths <- c(rep(n1,ncol),n1/max(1,10-ncol))
-      heights <- rep(n2,nrow)
-    }
-    widths <- widths/sum(widths)
-    heights <- heights/sum(heights)
-    layout(mat,widths=widths,heights=heights)
-    for(i in 1:nrow){
-      for(j in 1:ncol){
-        k <- (i-1)*ncol + j
-        if(k>nslice) break
-        if(view=="sagittal"){
-          image(-indy[n2:1]*pdim[2],indz*pdim[3],template[slices[k],n2:1,],col=grey(0:255/255),asp=TRUE,xlab="-yind")
-          title(paste("sagittal slice",indx[slices[k]]))
-          image(-indy[n2:1]*pdim[2],indz*pdim[3],lpvalue[slices[k],n2:1,],zlim=rlp,add=TRUE,col=heat.colors(256),asp=TRUE)
-        }
-        if(view=="coronal"){
-          image(indx*pdim[1],indz*pdim[3],template[,slices[k],],col=grey(0:255/255),asp=TRUE)
-          title(paste("coronal slice",indy[slices[k]]))
-          image(indx*pdim[1],indz*pdim[3],lpvalue[,slices[k],],zlim=rlp,add=TRUE,col=heat.colors(256),asp=TRUE)
-        }
-        if(view=="axial"){
-          image(indx*pdim[1],indy*pdim[2],template[,,slices[k]],col=grey(0:255/255),asp=TRUE)
-          title(paste("axial slice", indz[slices[k]]))
-          image(indx*pdim[1],indy*pdim[2],lpvalue[,,slices[k]],zlim=rlp,add=TRUE,col=heat.colors(256),asp=TRUE)
-        }
-      }
-      scalep <- seq(rlp[1],rlp[2],length=256)
-      scalep <- t(matrix(scalep,length(scalep),10))
-      image(1:10,scalep[1,],scalep,col=heat.colors(256),xaxt="n",xlab="",ylab="-log(pvalue)")
-    }
-    # if(k>nslice) break
-  }
-  invisible(list(slices=slices,center=center))
-}
-getAlignedCoords <- function(spm,T1){
-  if(class(T1)=="nifti"){
-  qformcode <- spm$header$qformcode
-  sformcode <- spm$header$sformcode
-if(qformcode==1){
-  qformcodeT1 <- T1@qform_code
-  if(qformcodeT1!=1) stop(" can't realign with T1")
-  if(T1@quatern_b!=spm$header$quaternb) stop("coordinate systems don't coincide")
-  if(T1@quatern_c!=spm$header$quaternc) stop("coordinate systems don't coincide")
-  if(T1@quatern_d!=spm$header$quaternd) stop("coordinate systems don't coincide")
-  if(T1@qoffset_x!=spm$header$qoffsetx) stop("coordinate systems don't coincide")
-  if(T1@qoffset_y!=spm$header$qoffsety) stop("coordinate systems don't coincide")
-  if(T1@qoffset_z!=spm$header$qoffsetz) stop("coordinate systems don't coincide")
-}
-if(sformcode==1){
-  sformcodeT1 <- T1@sform_code
-  if(sformcodeT1!=1) stop(" can't realign with T1")
-  if(any(T1@srow_x!=spm$header$srowx)) stop("coordinate systems don't coincide")
-  if(any(T1@srow_y!=spm$header$srowy)) stop("coordinate systems don't coincide")
-  if(any(T1@srow_z!=spm$header$srowz)) stop("coordinate systems don't coincide")
-}
-  pixdimT1 <- T1@pixdim
-  pixdimspm <- spm$header$pixdim
-
-  ixT1 <- round((1:spm$dim[1]-1/2)*pixdimspm[2]/pixdimT1[2]+1/2)
-  iyT1 <- round((1:spm$dim[2]-1/2)*pixdimspm[3]/pixdimT1[3]+1/2)
-  izT1 <- round((1:spm$dim[3]-1/2)*pixdimspm[4]/pixdimT1[4]+1/2)
-  ixT1 <- ixT1[ixT1%in%1:T1@dim_[2]]
-  iyT1 <- iyT1[iyT1%in%1:T1@dim_[3]]
-  izT1 <- izT1[izT1%in%1:T1@dim_[4]]
-
-  ixspm <- round((1:T1@dim_[2]-1/2)/pixdimspm[2]*pixdimT1[2]+1/2)
-  iyspm <- round((1:T1@dim_[3]-1/2)/pixdimspm[3]*pixdimT1[3]+1/2)
-  izspm <- round((1:T1@dim_[4]-1/2)/pixdimspm[4]*pixdimT1[4]+1/2)
-  ixspm <- ixspm[ixspm%in%1:spm$dim[1]]
-  iyspm <- iyspm[iyspm%in%1:spm$dim[2]]
-  izspm <- izspm[izspm%in%1:spm$dim[3]]
-  pdim <- T1@pixdim[2:4]
-  } else {
-    if(any(spm$dim[1:3]!=T1$dim[1:3])) stop(" can't realign with template")
-    ixT1 <- ixspm <- 1:spm$dim[1]
-    iyT1 <- iyspm <- 1:spm$dim[2]
-    izT1 <- izspm <- 1:spm$dim[3]
-    pdim <- spm$header$pixdim[2:4]
-  }
-  list(ixT1=ixT1, iyT1=iyT1, izT1=izT1, ixspm=ixspm, iyspm=iyspm, izspm=izspm, pixdim=pdim)
-}
 q2rot <- function(b,c,d){
    a <- sqrt(1-b^2-c^2-d^2)
    rot <- matrix(c(a^2+b^2-c^2-d^2, 2*b*c-2*a*d, 2*b*d+2*a*c,
@@ -391,6 +205,7 @@ q2rot <- function(b,c,d){
    rot
 }
 
+
 getAlignedCoords <- function(img1,img2){
 #
 #  compute indices of closest representants
